/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: CloseBlockerOutputStream.java 647537 2008-04-13 07:36:00Z jeremias $ */
 
package org.apache.fop.util;

import java.io.IOException;
import java.io.OutputStream;

import org.apache.commons.io.output.ProxyOutputStream;

/**
 * This is a decorator to block calls to close() to the underlying stream.
 */
public class CloseBlockerOutputStream extends ProxyOutputStream {

    /**
     * Main constructor.
     * @param out the underlying stream
     */
    public CloseBlockerOutputStream(OutputStream out) {
        super(out);
    }

    /** {@inheritDoc} */
    public void close() throws IOException {
        try {
            flush();
        } catch (IOException ioe) {
            //ignore
        }
    }

}
